@@ -190,8 +190,7 @@ class SSHClient(object):
         if os.path.isfile(local_path):
             subprocess.run(['rm', '-rf', local_path], capture_output=True, text=True)
         self.__sftp.get(remote_path, local_path)
-        rs = subprocess.Popen(['ls', local_path], stdout=subprocess.PIPE, stderr=subprocess.PIPE, text=True)
-        if rs.returncode == 0:
+        if os.path.exists(local_path):
             log.info(
                 f" {self.__ip}:{self.__port} | Success to copy file from remote {remote_path} to local host{local_path}:OK.")
             return True
